import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import {
  isOverlayActiveSelector,
  isOverlayLoadingSelector,
} from '@/redux/overlayBioEntity/overlayBioEntity.selector';
import { removeOverlayBioEntityForGivenOverlay } from '@/redux/overlayBioEntity/overlayBioEntity.slice';
import { getOverlayBioEntityForAllModels } from '@/redux/overlayBioEntity/overlayBioEntity.thunk';
import { BASE_API_URL } from '@/constants';
import { apiPath } from '@/redux/apiPath';
import { useEmptyBackground } from './useEmptyBackground';

type UseOverlay = {
  toggleOverlay: () => void;
  downloadOverlay: () => void;
  isOverlayActive: boolean;
  isOverlayLoading: boolean;
};

export const useOverlay = (overlayId: number): UseOverlay => {
  const dispatch = useAppDispatch();
  const isOverlayActive = useAppSelector(state => isOverlayActiveSelector(state, overlayId));
  const isOverlayLoading = useAppSelector(state => isOverlayLoadingSelector(state, overlayId));
  const { setBackgroundtoEmptyIfAvailable } = useEmptyBackground();

  const toggleOverlay = (): void => {
    if (isOverlayActive) {
      dispatch(removeOverlayBioEntityForGivenOverlay({ overlayId }));
    } else {
      setBackgroundtoEmptyIfAvailable();
      dispatch(getOverlayBioEntityForAllModels({ overlayId }));
    }
  };

  const downloadOverlay = (): void => {
    window.open(`${BASE_API_URL}/${apiPath.downloadOverlay(overlayId)}`, '_blank');
  };

  return { toggleOverlay, isOverlayActive, isOverlayLoading, downloadOverlay };
};
